# -*- coding: utf-8 -*-
'''
    The venvm is small webtool for manager virtualenv.
    Copyright (C) 2013  Rodrigo Pinheiro Matias <rodrigopmatias@gmail.com>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see {http://www.gnu.org/licenses/}.
'''
from flask import Flask, render_template
from db import setup_db
from argparse import ArgumentParser

import sys
import os
import re
import subprocess as sp
import venvm

app = Flask(__name__)


@app.route('/')
def index():
    return render_template('index.html')


@app.route('/manager')
def manager():
    return 'manager'


def get_directory_size(directory):
    pid = sp.Popen(['/usr/bin/du', '-sh', directory], stdout=sp.PIPE)
    regex = re.compile('^(?P<size>\d+(M|G|T|H)).*$')

    rst = regex.match(pid.stdout.read())
    if rst is not None:
        return rst.groupdict().get('size')
    else:
        return 'undefined'


@app.route('/information')
def search():
    params = {
        'py_version': '%s.%s.%s' % (sys.version_info.major, sys.version_info.minor, sys.version_info.micro),
        'py_platform': sys.platform,
        'py_api_version': sys.api_version,
        'py_copyright': sys.copyright,
        'size': get_directory_size(os.environ.get('VIRTUAL_ENV')),
        'path': os.environ.get('VIRTUAL_ENV')
    }

    try:
        import pip
    except Exception:
        pass
    else:
        params.update(
            pip={
                'version': pip.__version__
            }
        )

    try:
        import setuptools
    except Exception:
        pass
    else:
        params.update(
            setuptools={
                'version': setuptools.__version__
            }
        )

    try:
        import distutils
    except Exception:
        pass
    else:
        params.update(
            distutils={
                'version': distutils.__version__
            }
        )

    return render_template('information.html', **params)


@app.route('/install')
def install():
    return 'install'


def main():
    ps = ArgumentParser()

    ps.add_argument(
        '-d',
        '--debug',
        help='Enable debug mode.',
        dest='debug',
        action='store_true'
    )

    ps.add_argument(
        '-a',
        '--addr',
        help='Enable debug mode.',
        dest='host',
        default='127.0.0.1'
    )

    ps.add_argument(
        '-p',
        '--port',
        help='Port TCP to Listener http protocol.',
        dest='port',
        type=int
    )

    rst = ps.parse_args()
    setup_db()
    print('Running venvm version %s' % venvm.__version__)
    app.run(**rst.__dict__)


if __name__ == '__main__':
    main()
